==> aplus_chat-0.2.4.tar.gz: lib/view/widgets/video_player.dart <==
import 'dart:io';

import 'package:aplus_chat/helper/colors.dart';
import 'package:aplus_chat/helper/custom_styles.dart';
import 'package:chewie/chewie.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:video_player/video_player.dart';

class VideoPlayerView extends StatefulWidget {
  const VideoPlayerView({
    Key? key,
    this.videoFile,
    this.isVideoUrl,
  }) : super(key: key);
  final String? videoFile;
  final bool? isVideoUrl;
  @override
  VideoPlayerViewState createState() => VideoPlayerViewState();
}

class VideoPlayerViewState extends State<VideoPlayerView> {

  var mediaUrl = "".obs;
var chewieController;
VideoPlayerController? videoPlayerController;
  @override
  void initState() {
    super.initState();
    mediaUrl.value = widget.videoFile!;
    var isUrl = widget.isVideoUrl;
    playVideo(mediaUrl.value, isUrl);
  }

  playVideo(url, isUrl) async {
    if (isUrl) {
       videoPlayerController = VideoPlayerController.networkUrl(
         Uri.parse( url.toString()));

      await videoPlayerController!.initialize();

       chewieController = ChewieController(
        videoPlayerController: videoPlayerController!,
        autoPlay: true,
        looping: true,
      );
    } else {
       videoPlayerController = VideoPlayerController.file(
          File(url.toString()));

      await videoPlayerController!.initialize();

       chewieController = ChewieController(
        videoPlayerController: videoPlayerController!,
        autoPlay: true,
        looping: true,
      );
    }
  }

  @override
  void dispose() {
    super.dispose();
    videoPlayerController!.dispose();
    chewieController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          "Video",
          style: CustomTextStyles.medium(
            fontSize: 16.0,
            fontColor: Colors.black,
          ),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      body: Center(
        child: Chewie(
          controller: chewieController,
        ),
      ),
    );
  }
}

==> aplus_chat-0.2.14.tar.gz: lib/view/widgets/video_player.dart <==
import 'dart:io';

import 'package:aplus_chat/helper/colors.dart';
import 'package:aplus_chat/helper/custom_styles.dart';
import 'package:chewie/chewie.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:video_player/video_player.dart';

class VideoPlayerView extends StatefulWidget {
  const VideoPlayerView({
    Key? key,
    this.videoFile,
    this.isVideoUrl,
  }) : super(key: key);
  final String? videoFile;
  final bool? isVideoUrl;
  @override
  VideoPlayerViewState createState() => VideoPlayerViewState();
}

class VideoPlayerViewState extends State<VideoPlayerView> {

  var mediaUrl = "".obs;
var chewieController;
VideoPlayerController? videoPlayerController;
  @override
  void initState() {
    super.initState();
    mediaUrl.value = widget.videoFile!;
    var isUrl = widget.isVideoUrl;
    playVideo(mediaUrl.value, isUrl);
  }

  playVideo(url, isUrl) async {
    if (isUrl) {
       videoPlayerController = VideoPlayerController.networkUrl(
         Uri.parse( url.toString()));

      await videoPlayerController!.initialize(
      ).then((value) {
        setState(() {

        });
      });

       chewieController = ChewieController(
        videoPlayerController: videoPlayerController!,
        autoPlay: true,
        looping: true,
      );
    } else {
       videoPlayerController = VideoPlayerController.file(
          File(url.toString()));

      await videoPlayerController!.initialize().then((value) {
setState(() {});
      });

       chewieController = ChewieController(
        videoPlayerController: videoPlayerController!,
        autoPlay: true,
        looping: true,
         autoInitialize: true
      );

    }
  }

  @override
  void dispose() {
    super.dispose();
    videoPlayerController!.dispose();
    chewieController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          "Video",
          style: CustomTextStyles.medium(
            fontSize: 16.0,
            fontColor: Colors.black,
          ),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      body: Center(
        child: chewieController != null?Chewie(
          controller: chewieController,
        ):CircularProgressIndicator(),
      ),
    );
  }
}
